

.. _sphx_glr_content_user_guide_auto_examples_3multi:

3 | Multi-Set Analysis
========================



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we&#x27;re going to perform a Canonical Correlation Analysis (CCA) on three dataset...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/3multi/images/thumb/sphx_glr_plot_cca_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_3multi_plot_cca.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Canonical Correlation Analysis</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /content/user_guide/auto_examples/3multi/plot_cca

